@@ -347,6 +347,8 @@ def command_db(lookup, resources, options):
             print("RESOURCE: %s"%resource_name)
         print("DB [key -> resolution]")
         view = lookup.get_rosdep_view_for_resource(resource_name)
+        if view is None:
+            continue
         for rosdep_name in view.keys():
             try:
                 d = view.lookup(rosdep_name)
@@ -408,14 +410,16 @@ def command_resolve(args, options):
 
     for rosdep_name in args:
         if len(args) > 1:
-            print("rosdep[%s]"%rosdep_name)
+            print("#ROSDEP[%s]"%rosdep_name)
         view_names = lookup.get_views_that_define(rosdep_name)
         
         if not view_names:
             raise ResolutionError(rosdep_name, None, os_name, os_version, "Could not find definition for rosdep [%s]"%rosdep_name)
         for view_name, origin in view_names:
             print("#[%s:%s]"%(view_name, origin))
-            view = lookup.get_rosdep_view_for_resource(view_name)
+            view = lookup.get_rosdep_view(view_name)
+            if view is None:
+                continue
             d = view.lookup(rosdep_name)
             inst_key, rule = d.get_rule_for_platform(os_name, os_version, installer_keys, default_key)
 
